@@ -24,7 +24,10 @@ def submissions_command(config, canvas, args):
   output = csv.writer(sys.stdout, delimiter=args.delimiter)
 
   for submission in submissions:
-    output.writerow(format_submission_short(submission))
+    if args.login_id:
+      output.writerow(format_submission_short_unique(submission))
+    else:
+      output.writerow(format_submission_short(submission))
 def speedgrader(submission):
   """Returns the SpeedGrader URL of the submission"""
   speedgrader_url = submission.preview_url
@@ -101,6 +104,11 @@ def format_submission_short(submission):
   return [submission.assignment.course.course_code, submission.assignment.name,
     submission.user.name, submission.grade,
     submission.submitted_at, submission.graded_at]
+
+def format_submission_short_unique(submission):
+  return [submission.assignment.course.course_code, submission.assignment.name,
+    submission.user.login_id, submission.grade,
+    submission.submitted_at, submission.graded_at]
 def format_submission(submission, canvas):
   """Formats submission for printing to stdout"""
   student = submission.assignment.course.get_user(submission.user_id)
@@ -173,6 +181,9 @@ def add_submissions_command(subp):
   submissions_parser.set_defaults(func=submissions_command)
   assignments.add_assignment_option(submissions_parser)
   add_submission_options(submissions_parser)
+  submissions_parser.add_argument("-l", "--login-id",
+    help="Print login ID instead of name.",
+    default=False, action="store_true")
 
 def add_submission_command(subp):
   """Adds submission command to argparse parser subp"""
